@@ -10,19 +10,20 @@
 
 #include <eom-debug.h>
 #include <eom-window.h>
+#include <eom-window-activatable.h>
 
-static void peas_activatable_iface_init (PeasActivatableInterface *iface);
+static void eom_window_activatable_iface_init (EomWindowActivatableInterface *iface);
 
 G_DEFINE_DYNAMIC_TYPE_EXTENDED (EomFullscreenPlugin,
                                 eom_fullscreen_plugin,
                                 PEAS_TYPE_EXTENSION_BASE,
                                 0,
-                                G_IMPLEMENT_INTERFACE_DYNAMIC (PEAS_TYPE_ACTIVATABLE,
-                                                               peas_activatable_iface_init))
+                                G_IMPLEMENT_INTERFACE_DYNAMIC (EOM_TYPE_WINDOW_ACTIVATABLE,
+                                                               eom_window_activatable_iface_init))
 
 enum {
 	PROP_0,
-	PROP_OBJECT
+	PROP_WINDOW
 };
 
 static gboolean
@@ -59,8 +60,8 @@ eom_fullscreen_plugin_set_property (GObject      *object,
 
 	switch (prop_id)
 	{
-	case PROP_OBJECT:
-		plugin->window = GTK_WIDGET (g_value_dup_object (value));
+	case PROP_WINDOW:
+		plugin->window = EOM_WINDOW (g_value_dup_object (value));
 		break;
 
 	default:
@@ -79,7 +80,7 @@ eom_fullscreen_plugin_get_property (GObject    *object,
 
 	switch (prop_id)
 	{
-	case PROP_OBJECT:
+	case PROP_WINDOW:
 		g_value_set_object (value, plugin->window);
 		break;
 
@@ -111,10 +112,10 @@ eom_fullscreen_plugin_dispose (GObject *object)
 }
 
 static void
-eom_fullscreen_plugin_activate (PeasActivatable *activatable)
+eom_fullscreen_plugin_activate (EomWindowActivatable *activatable)
 {
 	EomFullscreenPlugin *plugin = EOM_FULLSCREEN_PLUGIN (activatable);
-	GtkWidget *view = eom_window_get_view (EOM_WINDOW (plugin->window));
+	GtkWidget *view = eom_window_get_view (plugin->window);
 
 	eom_debug (DEBUG_PLUGINS);
 
@@ -125,10 +126,10 @@ eom_fullscreen_plugin_activate (PeasActivatable *activatable)
 }
 
 static void
-eom_fullscreen_plugin_deactivate (PeasActivatable *activatable)
+eom_fullscreen_plugin_deactivate (EomWindowActivatable *activatable)
 {
 	EomFullscreenPlugin *plugin = EOM_FULLSCREEN_PLUGIN (activatable);
-	GtkWidget *view = eom_window_get_view (EOM_WINDOW (plugin->window));
+	GtkWidget *view = eom_window_get_view (plugin->window);
 
 	g_signal_handler_disconnect (view, plugin->signal_id);
 }
@@ -142,7 +143,7 @@ eom_fullscreen_plugin_class_init (EomFullscreenPluginClass *klass)
 	object_class->set_property = eom_fullscreen_plugin_set_property;
 	object_class->get_property = eom_fullscreen_plugin_get_property;
 
-	g_object_class_override_property (object_class, PROP_OBJECT, "object");
+	g_object_class_override_property (object_class, PROP_WINDOW, "window");
 }
 
 static void
@@ -152,7 +153,7 @@ eom_fullscreen_plugin_class_finalize (EomFullscreenPluginClass *klass)
 }
 
 static void
-peas_activatable_iface_init (PeasActivatableInterface *iface)
+eom_window_activatable_iface_init (EomWindowActivatableInterface *iface)
 {
 	iface->activate = eom_fullscreen_plugin_activate;
 	iface->deactivate = eom_fullscreen_plugin_deactivate;
@@ -163,6 +164,6 @@ peas_register_types (PeasObjectModule *module)
 {
 	eom_fullscreen_plugin_register_type (G_TYPE_MODULE (module));
 	peas_object_module_register_extension_type (module,
-	                                            PEAS_TYPE_ACTIVATABLE,
+	                                            EOM_TYPE_WINDOW_ACTIVATABLE,
 	                                            EOM_TYPE_FULLSCREEN_PLUGIN);
 }
