@@ -61,9 +61,6 @@
 
 #if defined(HAVE_LCMS) && defined(GDK_WINDOWING_X11)
 #include <lcms2.h>
-#ifndef EXIF_TAG_GAMMA
-#define EXIF_TAG_GAMMA 0xa500
-#endif
 #endif
 
 #ifdef HAVE_RSVG
@@ -84,8 +81,6 @@ enum {
 
 static guint signals[SIGNAL_LAST] = { 0 };
 
-static GList *supported_mime_types = NULL;
-
 #define EOM_IMAGE_READ_BUFFER_SIZE 65535
 
 static void
@@ -199,8 +194,7 @@ eom_image_dispose (GObject *object)
 	}
 
 	if (priv->undo_stack) {
-		g_slist_foreach (priv->undo_stack, (GFunc) g_object_unref, NULL);
-		g_slist_free (priv->undo_stack);
+		g_slist_free_full (priv->undo_stack, g_object_unref);
 		priv->undo_stack = NULL;
 	}
 
@@ -962,7 +956,7 @@ eom_image_real_load (EomImage *img,
 		}
 
 		if (!strcmp (mime_type, "image/svg+xml")
-#if LIBRSVG_CHECK_FEATURE(SVGZ)
+#if defined (LIBRSVG_HAVE_SVGZ) && LIBRSVG_HAVE_SVGZ
                     || !strcmp (mime_type, "image/svg+xml-compressed")
 #endif
                 ) {
@@ -986,8 +980,7 @@ eom_image_real_load (EomImage *img,
 			        loader = gdk_pixbuf_loader_new ();
 		        }
 
-		        g_signal_connect_object (G_OBJECT (loader),
-					         "size-prepared",
+		        g_signal_connect_object (loader, "size-prepared",
 					         G_CALLBACK (eom_image_size_prepared),
 					         img,
 					         0);
@@ -1463,8 +1456,7 @@ transfer_progress_cb (goffset cur_bytes,
 	EomImage *image = EOM_IMAGE (user_data);
 
 	if (cur_bytes > 0) {
-		g_signal_emit (G_OBJECT(image),
-			       signals[SIGNAL_SAVE_PROGRESS],
+		g_signal_emit (image, signals[SIGNAL_SAVE_PROGRESS],
 			       0,
 			       (gfloat) cur_bytes / (gfloat) total_bytes);
 	}
@@ -1649,8 +1641,7 @@ eom_image_reset_modifications (EomImage *image)
 
 	priv = image->priv;
 
-	g_slist_foreach (priv->undo_stack, (GFunc) g_object_unref, NULL);
-	g_slist_free (priv->undo_stack);
+	g_slist_free_full (priv->undo_stack, g_object_unref);
 	priv->undo_stack = NULL;
 
 	if (priv->trans != NULL) {
@@ -1957,7 +1948,7 @@ eom_image_get_caption (EomImage *img)
 				/* Guaranteed to be correct utf8 here */
 				validated = TRUE;
 			}
-		} else if (!broken_filenames) {
+		} else {
 			/* name was valid, no need to re-validate */
 			validated = TRUE;
 		}
@@ -2117,7 +2108,7 @@ eom_image_modified (EomImage *img)
 {
 	g_return_if_fail (EOM_IS_IMAGE (img));
 
-	g_signal_emit (G_OBJECT (img), signals[SIGNAL_CHANGED], 0);
+	g_signal_emit (img, signals[SIGNAL_CHANGED], 0);
 }
 
 gchar*
@@ -2219,11 +2210,12 @@ compare_quarks (gconstpointer a, gconstpointer b)
 GList *
 eom_image_get_supported_mime_types (void)
 {
+	static GList *supported_mime_types = NULL;
 	GSList *format_list, *it;
 	gchar **mime_types;
 	int i;
 
-	if (!supported_mime_types) {
+	if (supported_mime_types == NULL) {
 		format_list = gdk_pixbuf_get_formats ();
 
 		for (it = format_list; it != NULL; it = it->next) {
@@ -2251,18 +2243,16 @@ eom_image_get_supported_mime_types (void)
 gboolean
 eom_image_is_supported_mime_type (const char *mime_type)
 {
-	GList *supported_mime_types, *result;
+	GList *result;
 	GQuark quark;
 
 	if (mime_type == NULL) {
 		return FALSE;
 	}
 
-	supported_mime_types = eom_image_get_supported_mime_types ();
-
 	quark = g_quark_from_string (mime_type);
 
-	result = g_list_find_custom (supported_mime_types,
+	result = g_list_find_custom (eom_image_get_supported_mime_types (),
 				     GINT_TO_POINTER (quark),
 				     (GCompareFunc) compare_quarks);
 
@@ -2448,4 +2438,3 @@ eom_image_is_jpeg (EomImage *img)
 
 	return ((img->priv->file_type != NULL) && (g_ascii_strcasecmp (img->priv->file_type, EOM_FILE_FORMAT_JPEG) == 0));
 }
-
