@@ -29,9 +29,6 @@
 
 #include <string.h>
 
-#define EOM_LIST_STORE_GET_PRIVATE(object) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOM_TYPE_LIST_STORE, EomListStorePrivate))
-
 struct _EomListStorePrivate {
 	GList *monitors;          /* Monitors for the directories */
 	gint initial_image;       /* The image that should be selected firstly by the view. */
@@ -410,8 +407,6 @@ file_monitor_changed_cb (GFileMonitor *monitor,
 		break;
 	case G_FILE_MONITOR_EVENT_DELETED:
 		if (is_file_in_list_store_file (store, file, &iter)) {
-			EomImage *image;
-
 			gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
 					    EOM_LIST_STORE_EOM_IMAGE, &image,
 					    -1);
