@@ -19,10 +19,6 @@
 
 #include <gdk/gdk.h>
 
-/* Maximum size of delayed repaint rectangles */
-#define PAINT_RECT_WIDTH 128
-#define PAINT_RECT_HEIGHT 128
-
 /* Scroll step increment */
 #define SCROLL_STEP_SIZE 32
 
@@ -32,10 +28,8 @@
 
 #define CHECK_MEDIUM 8
 #define CHECK_BLACK "#000000"
-#define CHECK_DARK "#555555"
 #define CHECK_GRAY "#808080"
 #define CHECK_LIGHT "#cccccc"
-#define CHECK_WHITE "#ffffff"
 
 /* Default increment for zooming.  The current zoom factor is multiplied or
  * divided by this amount on every zooming step.  For consistency, you should
@@ -195,12 +189,12 @@ free_image_resources (EomScrollView *view)
 	priv = view->priv;
 
 	if (priv->image_changed_id > 0) {
-		g_signal_handler_disconnect (G_OBJECT (priv->image), priv->image_changed_id);
+		g_signal_handler_disconnect (priv->image, priv->image_changed_id);
 		priv->image_changed_id = 0;
 	}
 
 	if (priv->frame_changed_id > 0) {
-		g_signal_handler_disconnect (G_OBJECT (priv->image), priv->frame_changed_id);
+		g_signal_handler_disconnect (priv->image, priv->frame_changed_id);
 		priv->frame_changed_id = 0;
 	}
 
@@ -297,14 +291,14 @@ update_scrollbar_values (EomScrollView *view)
 
 	priv = view->priv;
 
-	if (!gtk_widget_get_visible (GTK_WIDGET (priv->hbar))
-	    && !gtk_widget_get_visible (GTK_WIDGET (priv->vbar)))
+	if (!gtk_widget_get_visible (priv->hbar)
+	    && !gtk_widget_get_visible (priv->vbar))
 		return;
 
 	compute_scaled_size (view, priv->zoom, &scaled_width, &scaled_height);
-	gtk_widget_get_allocation (GTK_WIDGET (priv->display), &allocation);
+	gtk_widget_get_allocation (priv->display, &allocation);
 
-	if (gtk_widget_get_visible (GTK_WIDGET (priv->hbar))) {
+	if (gtk_widget_get_visible (priv->hbar)) {
 		/* Set scroll increments */
 		page_size = MIN (scaled_width, allocation.width);
 
@@ -329,7 +323,7 @@ update_scrollbar_values (EomScrollView *view)
 			0, 0, NULL, NULL, view);
 	}
 
-	if (gtk_widget_get_visible (GTK_WIDGET (priv->vbar))) {
+	if (gtk_widget_get_visible (priv->vbar)) {
 		page_size = MIN (scaled_height, allocation.height);
 		page_increment = allocation.height / 2;
 		step_increment = SCROLL_STEP_SIZE;
@@ -447,10 +441,10 @@ check_scrollbar_visibility (EomScrollView *view, GtkAllocation *alloc)
 			hbar_visible = TRUE;
 	}
 
-	if (hbar_visible != gtk_widget_get_visible (GTK_WIDGET (priv->hbar)))
+	if (hbar_visible != gtk_widget_get_visible (priv->hbar))
 		g_object_set (G_OBJECT (priv->hbar), "visible", hbar_visible, NULL);
 
-	if (vbar_visible != gtk_widget_get_visible (GTK_WIDGET (priv->vbar)))
+	if (vbar_visible != gtk_widget_get_visible (priv->vbar))
 		g_object_set (G_OBJECT (priv->vbar), "visible", vbar_visible, NULL);
 }
 
@@ -600,14 +594,14 @@ scroll_to (EomScrollView *view, int x, int y, gboolean change_adjustments)
 	if (!gtk_widget_is_drawable (priv->display))
 		goto out;
 
-	gtk_widget_get_allocation (GTK_WIDGET (priv->display), &allocation);
+	gtk_widget_get_allocation (priv->display, &allocation);
 
 	if (abs (xofs) >= allocation.width || abs (yofs) >= allocation.height) {
-		gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+		gtk_widget_queue_draw (priv->display);
 		goto out;
 	}
 
-	window = gtk_widget_get_window (GTK_WIDGET (priv->display));
+	window = gtk_widget_get_window (priv->display);
 
 	gdk_window_scroll (window, -xofs, -yofs);
 
@@ -660,7 +654,7 @@ adjustment_changed_cb (GtkAdjustment *adj, gpointer data)
 	scroll_to (view, gtk_adjustment_get_value (priv->hadj),
 		   gtk_adjustment_get_value (priv->vadj), FALSE);
 
-	gtk_widget_queue_resize (view);
+	gtk_widget_queue_resize (GTK_WIDGET (view));
 }
 
 
@@ -734,7 +728,7 @@ set_zoom (EomScrollView *view, double zoom,
 
 	priv->zoom_mode = ZOOM_MODE_FREE;
 
-	gtk_widget_get_allocation (GTK_WIDGET (priv->display), &allocation);
+	gtk_widget_get_allocation (priv->display, &allocation);
 
 	/* compute new xofs/yofs values */
 	if (have_anchor) {
@@ -766,9 +760,9 @@ set_zoom (EomScrollView *view, double zoom,
 	update_scrollbar_values (view);
 
 	/* repaint the whole image */
-	gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+	gtk_widget_queue_draw (priv->display);
 
-	g_signal_emit (view, view_signals [SIGNAL_ZOOM_CHANGED], 0, priv->zoom);
+	g_signal_emit (view, view_signals[SIGNAL_ZOOM_CHANGED], 0, priv->zoom);
 }
 
 /* Zooms the image to fit the available allocation */
@@ -789,7 +783,7 @@ set_zoom_fit (EomScrollView *view)
 	if (priv->pixbuf == NULL)
 		return;
 
-	gtk_widget_get_allocation (GTK_WIDGET(priv->display), &allocation);
+	gtk_widget_get_allocation (priv->display, &allocation);
 
 	new_zoom = zoom_fit_scale (allocation.width, allocation.height,
 				   gdk_pixbuf_get_width (priv->pixbuf) / priv->scale,
@@ -805,7 +799,7 @@ set_zoom_fit (EomScrollView *view)
 	priv->xofs = 0;
 	priv->yofs = 0;
 
-	g_signal_emit (view, view_signals [SIGNAL_ZOOM_CHANGED], 0, priv->zoom);
+	g_signal_emit (view, view_signals[SIGNAL_ZOOM_CHANGED], 0, priv->zoom);
 }
 
 /*===================================
@@ -834,7 +828,7 @@ display_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer data)
 	xofs = yofs = 0;
 	zoom = 1.0;
 
-	gtk_widget_get_allocation (GTK_WIDGET (priv->display), &allocation);
+	gtk_widget_get_allocation (priv->display, &allocation);
 
 	/* EomScrollView doesn't handle/have any Alt+Key combos */
 	if (event->state & GDK_MOD1_MASK) {
@@ -941,7 +935,7 @@ eom_scroll_view_button_press_event (GtkWidget *widget, GdkEventButton *event, gp
 	priv = view->priv;
 
 	if (!gtk_widget_has_focus (priv->display))
-		gtk_widget_grab_focus (GTK_WIDGET (priv->display));
+		gtk_widget_grab_focus (priv->display);
 
 	if (priv->dragging)
 		return FALSE;
@@ -1089,7 +1083,7 @@ eom_scroll_view_motion_event (GtkWidget *widget, GdkEventMotion *event, gpointer
 		return FALSE;
 
 	if (event->is_hint)
-		gdk_window_get_device_position (gtk_widget_get_window (GTK_WIDGET (priv->display)), event->device, &x, &y, &mods);
+		gdk_window_get_device_position (gtk_widget_get_window (priv->display), event->device, &x, &y, &mods);
 	else {
 		x = event->x;
 		y = event->y;
@@ -1112,7 +1106,7 @@ display_map_event (GtkWidget *widget, GdkEvent *event, gpointer data)
 
 	set_zoom_fit (view);
 	check_scrollbar_visibility (view, NULL);
-	gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+	gtk_widget_queue_draw (priv->display);
 }
 
 static void
@@ -1144,7 +1138,7 @@ display_size_change (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
 
 		set_zoom_fit (view);
 		check_scrollbar_visibility (view, &alloc);
-		gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+		gtk_widget_queue_draw (priv->display);
 	} else {
 		int scaled_width, scaled_height;
 		int x_offset = 0;
@@ -1167,19 +1161,19 @@ display_size_change (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
 
 static gboolean
 eom_scroll_view_focus_in_event (GtkWidget     *widget,
-			    GdkEventFocus *event,
-			    gpointer data)
+                                GdkEventFocus *event,
+                                gpointer       data)
 {
-	g_signal_stop_emission_by_name (G_OBJECT (widget), "focus_in_event");
+	g_signal_stop_emission_by_name (widget, "focus_in_event");
 	return FALSE;
 }
 
 static gboolean
 eom_scroll_view_focus_out_event (GtkWidget     *widget,
-			     GdkEventFocus *event,
-			     gpointer data)
+                                 GdkEventFocus *event,
+                                 gpointer       data)
 {
-	g_signal_stop_emission_by_name (G_OBJECT (widget), "focus_out_event");
+	g_signal_stop_emission_by_name (widget, "focus_out_event");
 	return FALSE;
 }
 
@@ -1188,7 +1182,7 @@ static gboolean _hq_redraw_cb (gpointer user_data)
 	EomScrollViewPrivate *priv = EOM_SCROLL_VIEW (user_data)->priv;
 
 	priv->force_unfiltered = FALSE;
-	gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+	gtk_widget_queue_draw (priv->display);
 
 	priv->hq_redraw_timeout_source = NULL;
 	return G_SOURCE_REMOVE;
@@ -1244,7 +1238,7 @@ display_draw (GtkWidget *widget, cairo_t *cr, gpointer data)
 
 	compute_scaled_size (view, priv->zoom, &scaled_width, &scaled_height);
 
-	gtk_widget_get_allocation (GTK_WIDGET (priv->display), &allocation);
+	gtk_widget_get_allocation (priv->display, &allocation);
 
 	/* Compute image offsets with respect to the window */
 
@@ -1417,7 +1411,7 @@ image_changed_cb (EomImage *img, gpointer data)
 	set_zoom_fit (EOM_SCROLL_VIEW (data));
 	check_scrollbar_visibility (EOM_SCROLL_VIEW (data), NULL);
 
-	gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+	gtk_widget_queue_draw (priv->display);
 }
 
 /*===================================
@@ -1451,7 +1445,7 @@ eom_scroll_view_set_zoom_upscale (EomScrollView *view, gboolean upscale)
 
 		if (priv->zoom_mode == ZOOM_MODE_FIT) {
 			set_zoom_fit (view);
-			gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+			gtk_widget_queue_draw (priv->display);
 		}
 	}
 }
@@ -1470,7 +1464,7 @@ eom_scroll_view_set_antialiasing_in (EomScrollView *view, gboolean state)
 
 	if (priv->interp_type_in != new_interp_type) {
 		priv->interp_type_in = new_interp_type;
-		gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+		gtk_widget_queue_draw (priv->display);
 		g_object_notify (G_OBJECT (view), "antialiasing-in");
 	}
 }
@@ -1489,7 +1483,7 @@ eom_scroll_view_set_antialiasing_out (EomScrollView *view, gboolean state)
 
 	if (priv->interp_type_out != new_interp_type) {
 		priv->interp_type_out = new_interp_type;
-		gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+		gtk_widget_queue_draw (priv->display);
 		g_object_notify (G_OBJECT (view), "antialiasing-out");
 
 	}
@@ -1506,7 +1500,7 @@ _transp_background_changed (EomScrollView *view)
 			/* Will be recreated if needed during redraw */
 			priv->background_surface = NULL;
 		}
-		gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+		gtk_widget_queue_draw (priv->display);
 	}
 
 }
@@ -1633,7 +1627,7 @@ eom_scroll_view_zoom_fit (EomScrollView *view)
 
 	set_zoom_fit (view);
 	check_scrollbar_visibility (view, NULL);
-	gtk_widget_queue_draw (GTK_WIDGET (view->priv->display));
+	gtk_widget_queue_draw (view->priv->display);
 }
 
 void
@@ -1684,7 +1678,7 @@ display_next_frame_cb (EomImage *image, gint delay, gpointer data)
 	priv = view->priv;
 
 	update_pixbuf (view, eom_image_get_pixbuf (image));
-	gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+	gtk_widget_queue_draw (priv->display);
 }
 
 void
@@ -1713,16 +1707,18 @@ eom_scroll_view_set_image (EomScrollView *view, EomImage *image)
 			update_pixbuf (view, eom_image_get_pixbuf (image));
 			set_zoom_fit (view);
 			check_scrollbar_visibility (view, NULL);
-			gtk_widget_queue_draw (GTK_WIDGET (priv->display));
+			gtk_widget_queue_draw (priv->display);
 
 		}
 
 		priv->image_changed_id = g_signal_connect (image, "changed",
-							   (GCallback) image_changed_cb, view);
+		                                           G_CALLBACK (image_changed_cb),
+		                                           view);
 		if (eom_image_is_animation (image) == TRUE ) {
 			eom_image_start_animation (image);
 			priv->frame_changed_id = g_signal_connect (image, "next-frame",
-								    (GCallback) display_next_frame_cb, view);
+			                                           G_CALLBACK (display_next_frame_cb),
+			                                           view);
 		}
 	}
 
@@ -1757,8 +1753,8 @@ eom_scroll_view_get_image (EomScrollView *view)
 gboolean
 eom_scroll_view_scrollbars_visible (EomScrollView *view)
 {
-	if (!gtk_widget_get_visible (GTK_WIDGET (view->priv->hbar)) &&
-	    !gtk_widget_get_visible (GTK_WIDGET (view->priv->vbar)))
+	if (!gtk_widget_get_visible (view->priv->hbar) &&
+	    !gtk_widget_get_visible (view->priv->vbar))
 		return FALSE;
 
 	return TRUE;
@@ -1833,22 +1829,22 @@ eom_scroll_view_init (EomScrollView *view)
 
 	priv->hadj = GTK_ADJUSTMENT (gtk_adjustment_new (0, 100, 0, 10, 10, 100));
 	g_signal_connect (priv->hadj, "value_changed",
-			  G_CALLBACK (adjustment_changed_cb),
-			  view);
+	                  G_CALLBACK (adjustment_changed_cb),
+	                  view);
 
 	priv->hbar = gtk_scrollbar_new (GTK_ORIENTATION_HORIZONTAL, priv->hadj);
 	priv->vadj = GTK_ADJUSTMENT (gtk_adjustment_new (0, 100, 0, 10, 10, 100));
 	g_signal_connect (priv->vadj, "value_changed",
-			  G_CALLBACK (adjustment_changed_cb),
-			  view);
+	                  G_CALLBACK (adjustment_changed_cb),
+	                  view);
 
 	priv->vbar = gtk_scrollbar_new (GTK_ORIENTATION_VERTICAL, priv->vadj);
 	priv->display = g_object_new (GTK_TYPE_DRAWING_AREA,
 				      "can-focus", TRUE,
 				      NULL);
-	priv->scale = gtk_widget_get_scale_factor (GTK_WIDGET (priv->display));
+	priv->scale = gtk_widget_get_scale_factor (priv->display);
 
-	gtk_widget_add_events (GTK_WIDGET (priv->display),
+	gtk_widget_add_events (priv->display,
 			       GDK_EXPOSURE_MASK
 			       | GDK_BUTTON_PRESS_MASK
 			       | GDK_BUTTON_RELEASE_MASK
@@ -1856,37 +1852,59 @@ eom_scroll_view_init (EomScrollView *view)
 			       | GDK_POINTER_MOTION_HINT_MASK
 			       | GDK_SCROLL_MASK
 			       | GDK_KEY_PRESS_MASK);
-	g_signal_connect (G_OBJECT (priv->display), "configure_event",
-			  G_CALLBACK (display_size_change), view);
-	g_signal_connect (G_OBJECT (priv->display), "draw", G_CALLBACK (display_draw), view);
-	g_signal_connect (G_OBJECT (priv->display), "map_event",
-			  G_CALLBACK (display_map_event), view);
-	g_signal_connect (G_OBJECT (priv->display), "button_press_event",
-			  G_CALLBACK (eom_scroll_view_button_press_event),
-			  view);
-	g_signal_connect (G_OBJECT (priv->display), "motion_notify_event",
-			  G_CALLBACK (eom_scroll_view_motion_event), view);
-	g_signal_connect (G_OBJECT (priv->display), "button_release_event",
-			  G_CALLBACK (eom_scroll_view_button_release_event),
-			  view);
-	g_signal_connect (G_OBJECT (priv->display), "scroll_event",
-			  G_CALLBACK (eom_scroll_view_scroll_event), view);
-	g_signal_connect (G_OBJECT (priv->display), "focus_in_event",
-			  G_CALLBACK (eom_scroll_view_focus_in_event), NULL);
-	g_signal_connect (G_OBJECT (priv->display), "focus_out_event",
-			  G_CALLBACK (eom_scroll_view_focus_out_event), NULL);
 
-	g_signal_connect (G_OBJECT (view), "key_press_event",
-			  G_CALLBACK (display_key_press_event), view);
+	g_signal_connect (priv->display, "configure_event",
+	                  G_CALLBACK (display_size_change),
+	                  view);
+
+	g_signal_connect (priv->display, "draw",
+	                  G_CALLBACK (display_draw),
+	                  view);
+
+	g_signal_connect (priv->display, "map_event",
+	                  G_CALLBACK (display_map_event),
+	                  view);
+
+	g_signal_connect (priv->display, "button_press_event",
+	                  G_CALLBACK (eom_scroll_view_button_press_event),
+	                  view);
+
+	g_signal_connect (priv->display, "motion_notify_event",
+	                  G_CALLBACK (eom_scroll_view_motion_event),
+	                  view);
+
+	g_signal_connect (priv->display, "button_release_event",
+	                  G_CALLBACK (eom_scroll_view_button_release_event),
+	                  view);
+
+	g_signal_connect (priv->display, "scroll_event",
+	                  G_CALLBACK (eom_scroll_view_scroll_event),
+	                  view);
+
+	g_signal_connect (priv->display, "focus_in_event",
+	                  G_CALLBACK (eom_scroll_view_focus_in_event),
+	                  NULL);
+
+	g_signal_connect (priv->display, "focus_out_event",
+	                  G_CALLBACK (eom_scroll_view_focus_out_event),
+	                  NULL);
+
+	g_signal_connect (view, "key_press_event",
+	                  G_CALLBACK (display_key_press_event),
+	                  view);
 
 	gtk_drag_source_set (priv->display, GDK_BUTTON1_MASK,
 			     target_table, G_N_ELEMENTS (target_table),
 			     GDK_ACTION_COPY | GDK_ACTION_MOVE |
 			     GDK_ACTION_LINK | GDK_ACTION_ASK);
-	g_signal_connect (G_OBJECT (priv->display), "drag-data-get",
-			  G_CALLBACK (view_on_drag_data_get_cb), view);
-	g_signal_connect (G_OBJECT (priv->display), "drag-begin",
-			  G_CALLBACK (view_on_drag_begin_cb), view);
+
+	g_signal_connect (priv->display, "drag-data-get",
+	                  G_CALLBACK (view_on_drag_data_get_cb),
+	                  view);
+
+	g_signal_connect (priv->display, "drag-begin",
+	                  G_CALLBACK (view_on_drag_begin_cb),
+	                  view);
 
 	gtk_grid_attach (GTK_GRID (view), priv->display,
 					 0, 0, 1, 1);
@@ -2265,8 +2283,9 @@ eom_scroll_view_set_popup (EomScrollView *view,
 				   GTK_WIDGET (view),
 				   NULL);
 
-	g_signal_connect (G_OBJECT (view), "button_press_event",
-			  G_CALLBACK (view_on_button_press_event_cb), NULL);
+	g_signal_connect (view, "button_press_event",
+	                  G_CALLBACK (view_on_button_press_event_cb),
+	                  NULL);
 }
 
 static gboolean
