@@ -79,8 +79,7 @@ eom_uri_converter_dispose (GObject *object)
 	}
 
 	if (priv->token_list) {
-		g_list_foreach (priv->token_list, (GFunc) free_token, NULL);
-		g_list_free (priv->token_list);
+		g_list_free_full (priv->token_list, free_token);
 		priv->token_list = NULL;
 	}
 
@@ -795,7 +794,7 @@ eom_uri_converter_do (EomURIConverter *conv, EomImage *image,
 
 	repl_str = replace_remove_chars (str, priv->convert_spaces, priv->space_character);
 
-	if (repl_str->len > 0) {
+	if ((repl_str != NULL) && (repl_str->len > 0)) {
 		build_absolute_file (conv, image, repl_str, file, format);
 	}
 
